# Format
# <top><left><right><bottom>_<top-left><top-right><bottom-left><bottom-right>_<content>

# Chunk 1 (tile edges)
# - W: wall
# - D: door
# - S: shortcut
# - x: none

# Chunk 2 (tile corners)
# - C: corner pixel
# - x: none

# Chunk 3 (tile content)
# - N: navigation room
# - S: save room
# - R: recharge room
# - H: hidden recharge room
# - D: data room
# - I: item
# - B: boss
# - G: gunship
# - P: gunship edge
# - x: none

COLORED_DOOR_TILES = {
    0x005: "WDxx_xxxx_x",
    0x006: "DDxx_xxxx_x",
    0x007: "DDxx_xxxC_x",
    0x008: "DDDD_xxxx_x",
    0x009: "DDDx_xxxx_x",
    0x00A: "WDxx_xxxx_x",
    0x00B: "DDxx_xxxx_x",
    0x00C: "DDxx_xxxC_x",
    0x00D: "DDDD_xxxx_x",
    0x00E: "DDDx_xxxx_x",
    0x00F: "WDxx_xxxx_x",
    0x010: "DDxx_xxxx_x",
    0x011: "DDxx_xxxC_x",
    0x012: "DDDD_xxxx_x",
    0x013: "DDDx_xxxx_x",
    0x014: "WDxx_xxxx_x",
    0x015: "DDxx_xxxx_x",
    0x016: "DDxx_xxxC_x",
    0x017: "DDDD_xxxx_x",
    0x018: "DDDx_xxxx_x",
    0x019: "DDDx_xxxx_x",
    0x01A: "DDDx_xxxx_x",
    0x01B: "DDDx_xxxx_x",
    0x01C: "DDDx_xxxx_x",
    0x01D: "DDDx_xxxx_x",
    0x01E: "DDDx_xxxx_x",
    0x01F: "DDDD_xxxx_x",
    0x025: "xDxx_xxxx_x",
    0x026: "xDxx_xCxC_x",
    0x027: "DDWD_xxxx_x",
    0x028: "DDDx_xxxx_x",
    0x029: "DDDW_xxxx_x",
    0x02A: "xDxx_xxxx_x",
    0x02B: "xDxx_xCxC_x",
    0x02C: "DDWD_xxxx_x",
    0x02D: "DDDx_xxxx_x",
    0x02E: "DDDW_xxxx_x",
    0x02F: "xDxx_xxxx_x",
    0x030: "xDxx_xCxC_x",
    0x031: "DDWD_xxxx_x",
    0x032: "DDDx_xxxx_x",
    0x033: "DDDW_xxxx_x",
    0x034: "xDxx_xxxx_x",
    0x035: "xDxx_xCxC_x",
    0x036: "DDWD_xxxx_x",
    0x037: "DDDx_xxxx_x",
    0x038: "DDDW_xxxx_x",
    0x039: "DDDW_xxxx_x",
    0x03A: "DDDW_xxxx_x",
    0x03B: "DDDW_xxxx_x",
    0x03C: "DDDW_xxxx_x",
    0x03D: "DDDW_xxxx_x",
    0x03E: "DDDW_xxxx_x",
    0x03F: "DDDD_xxxx_x",
    0x045: "WDxW_xxxx_x",
    0x046: "DDxD_xxxx_x",
    0x047: "DDxW_xxxx_x",
    0x048: "WDWW_xxxx_x",
    0x049: "WDDW_xxxx_x",
    0x04A: "WDxW_xxxx_x",
    0x04B: "DDxD_xxxx_x",
    0x04C: "DDxW_xxxx_x",
    0x04D: "WDWW_xxxx_x",
    0x04E: "WDDW_xxxx_x",
    0x04F: "WDxW_xxxx_x",
    0x050: "DDxD_xxxx_x",
    0x051: "DDxW_xxxx_x",
    0x052: "WDWW_xxxx_x",
    0x053: "WDDW_xxxx_x",
    0x054: "WDxW_xxxx_x",
    0x055: "DDxD_xxxx_x",
    0x056: "DDxW_xxxx_x",
    0x057: "WDWW_xxxx_x",
    0x058: "WDDW_xxxx_x",
    0x059: "WDDW_xxxx_x",
    0x05A: "WDDW_xxxx_x",
    0x05B: "WDDW_xxxx_x",
    0x05C: "WDDW_xxxx_x",
    0x05D: "WDDW_xxxx_x",
    0x05E: "WDDW_xxxx_x",
    0x05F: "DDDD_xxxx_x",
    0x065: "DDWx_xxxx_x",
    0x066: "WDDx_xxxx_x",
    0x068: "WDWx_xxxx_x",
    0x069: "WDDx_xxxx_x",
    0x06A: "DDWx_xxxx_x",
    0x06B: "WDDx_xxxx_x",
    0x06C: "WDxx_xxxC_x",
    0x06D: "WDWx_xxxx_x",
    0x06E: "WDDx_xxxx_x",
    0x06F: "DDWx_xxxx_x",
    0x070: "WDDx_xxxx_x",
    0x072: "WDWx_xxxx_x",
    0x073: "WDDx_xxxx_x",
    0x074: "DDWx_xxxx_x",
    0x075: "WDDx_xxxx_x",
    0x077: "WDWx_xxxx_x",
    0x078: "WDDx_xxxx_x",
    0x079: "WDDx_xxxx_x",
    0x07A: "WDDx_xxxx_x",
    0x07B: "WDDx_xxxx_x",
    0x07C: "WDDx_xxxx_x",
    0x07D: "WDDx_xxxx_x",
    0x07E: "WDDx_xxxx_x",
    0x07F: "DDDD_xxxx_x",
    0x085: "DDWW_xxxx_x",
    0x086: "xDDx_xxxx_x",
    0x088: "xDWx_xxxx_x",
    0x089: "xDDx_xxxx_x",
    0x08A: "DDWW_xxxx_x",
    0x08B: "xDDx_xxxx_x",
    0x08D: "xDWx_xxxx_x",
    0x08E: "xDDx_xxxx_x",
    0x08F: "DDWW_xxxx_x",
    0x090: "xDDx_xxxx_x",
    0x092: "xDWx_xxxx_x",
    0x093: "xDDx_xxxx_x",
    0x094: "DDWW_xxxx_x",
    0x095: "xDDx_xxxx_x",
    0x096: "DDDD_xxxx_x",
    0x097: "xDWx_xxxx_x",
    0x098: "xDDx_xxxx_x",
    0x099: "xDDx_xxxx_x",
    0x09A: "xDDx_xxxx_x",
    0x09B: "xDDx_xxxx_x",
    0x09C: "xDDx_xxxx_x",
    0x09D: "xDDx_xxxx_x",
    0x09E: "xDDx_xxxx_x",
    0x09F: "DDDD_xxxx_x",
    0x0E6: "WDDW_xxxx_x",
    0x0E7: "DDDW_xxxx_x",
    0x0E8: "DDDD_xxxx_x",
    0x0EA: "DDxx_xxxC_x",
    0x0EB: "WDDW_xxxx_x",
    0x0EC: "DDDW_xxxx_x",
    0x0ED: "DDDD_xxxx_x",
    0x0EF: "DDxx_xxxC_x",
    0x0F0: "WDDW_xxxx_x",
    0x0F1: "DDDW_xxxx_x",
    0x0F2: "DDDD_xxxx_x",
    0x0F4: "DDxx_xxxC_x",
    0x0F5: "WDDW_xxxx_x",
    0x0F6: "DDDW_xxxx_x",
    0x0F7: "DDDD_xxxx_x",
    0x0F8: "WDxx_xxxC_x",
    0x128: "WDDW_xxxx_R",
    0x140: "WDWW_xxxx_R",
    0x141: "WWDW_xxxx_R",
    0x142: "WDDW_xxxx_R",
    0x143: "WDWW_xxxx_R",
    0x144: "WWDW_xxxx_R",
    0x145: "WDDW_xxxx_R",
    0x146: "WDWW_xxxx_R",
    0x147: "WWDW_xxxx_R",
    0x148: "WDDW_xxxx_R",
    0x149: "WDWW_xxxx_R",
    0x14A: "WWDW_xxxx_R",
    0x14B: "WDDW_xxxx_R",
    0x14C: "WDWW_xxxx_N",
    0x14D: "WWDW_xxxx_N",
    0x14E: "WDDW_xxxx_N",
    0x14F: "WDWW_xxxx_N",
    0x150: "WWDW_xxxx_N",
    0x151: "WDDW_xxxx_N",
    0x152: "WDWW_xxxx_N",
    0x153: "WWDW_xxxx_N",
    0x154: "WDDW_xxxx_N",
    0x155: "WDWW_xxxx_N",
    0x156: "WWDW_xxxx_N",
    0x157: "WDDW_xxxx_N",
    0x15E: "WDDW_xxxx_R",
    0x160: "WDWW_xxxx_D",
    0x161: "WWDW_xxxx_D",
    0x162: "WDDW_xxxx_D",
    0x163: "WDWW_xxxx_D",
    0x164: "WWDW_xxxx_D",
    0x165: "WDDW_xxxx_D",
    0x166: "WDWW_xxxx_D",
    0x167: "WWDW_xxxx_D",
    0x168: "WDDW_xxxx_D",
    0x169: "WDWW_xxxx_D",
    0x16A: "WWDW_xxxx_D",
    0x16B: "WDDW_xxxx_D",
    0x17E: "WDDW_xxxx_S",
    0x17F: "WDDW_xxxx_S",
    0x198: "WDWW_xxxx_I",
    0x199: "WDWW_xxxx_O",
    0x19E: "WDWW_xxxx_I",
    0x19F: "WDWW_xxxx_O",
    0x1AC: "WDDW_xxxx_I",
    0x1AD: "WDDW_xxxx_O",
}

NORMAL_DOOR_TILES = {
    "WWxx_xxxx_x": 0x000,
    "Wxxx_xxxx_x": 0x001,
    "DWxx_xxxx_x": 0x002,
    "Dxxx_xxxx_x": 0x003,
    "DWxx_xxxC_x": 0x004,
    "xWxx_xxxx_x": 0x020,
    "xDxx_xxxx_x": 0x021,
    "Wxxx_xxCC_x": 0x022,
    "xWxx_xCxC_x": 0x023,
    "DWWD_xxxx_x": 0x024,
    "WWxW_xxxx_x": 0x040,
    "WxxW_xxxx_x": 0x041,
    "DWxD_xxxx_x": 0x042,
    "DWxW_xxxx_x": 0x043,
    "DxxD_xxxx_x": 0x044,
    "DWWx_xxxx_x": 0x060,
    "WDWx_xxxx_x": 0x061,
    "WDDx_xxxx_x": 0x062,
    "WWWx_xxxx_x": 0x063,
    "DxxW_xxxx_x": 0x064,
    "DWWW_xxxx_x": 0x080,
    "xDWx_xxxx_x": 0x081,
    "xDDx_xxxx_x": 0x082,
    "xWWx_xxxx_x": 0x083,
    "WDDW_xxxx_x": 0x084,
    "WWWW_xxxx_x": 0x087,
    "DDxW_xxxx_x": 0x0E0,
    "DDxD_xxxx_x": 0x0E1,
    "DDWx_xxxx_x": 0x0E2,
    "DDDx_xxxx_x": 0x0E3,
    "WWxx_xxxC_x": 0x0E4,
    "xWxx_xxxC_x": 0x0E5,
    "Dxxx_xxCC_x": 0x100,
    "xDxx_xCxC_x": 0x101,
    "DDxx_xxxC_x": 0x102,
    # "DWxx_xxxC_x": 0x103,  # dupe of 0x004
    "WDxx_xxxC_x": 0x104,
    "xDxx_xCxx_x": 0x105,
    "DDWW_xxxx_x": 0x120,
    "DDDW_xxxx_x": 0x121,
    "DDWD_xxxx_x": 0x122,
    "DDDD_xxxx_x": 0x123,
    "WDWW_xxxx_x": 0x124,
    "WDxx_xxxx_x": 0x125,
    "xxxx_xxxx_x": 0x126,
    "Wxxx_xxxC_x": 0x127,
    "WDxW_xxxx_P": 0x129,
    "WxWW_xxxx_G": 0x12A,
    "WDxW_xxxx_x": 0x12B,
    "DDxx_xxxx_x": 0x12C,
    "WDWW_xxxx_H": 0x138,
    "WWDW_xxxx_H": 0x139,
    "WDDW_xxxx_H": 0x13A,
    "WDWW_xxxx_R": 0x158,
    "WWDW_xxxx_R": 0x159,
    "WDDW_xxxx_R": 0x15A,
    "WDWW_xxxx_D": 0x15B,
    "WWDW_xxxx_D": 0x15C,
    "WDDW_xxxx_D": 0x15D,
    "WDWW_xxxx_N": 0x178,
    "WWDW_xxxx_N": 0x179,
    "WDDW_xxxx_N": 0x17A,
    "WDWW_xxxx_S": 0x17B,
    "WWDW_xxxx_S": 0x17C,
    "WDDW_xxxx_S": 0x17D,
    "WDWW_xxxx_I": 0x180,
    "WDWW_xxxx_O": 0x181,
    "WWxW_xxxx_I": 0x182,
    "WWxW_xxxx_O": 0x183,
    "WDDW_xxxx_I": 0x184,
    "WDDW_xxxx_O": 0x185,
    "WWxx_xxxx_I": 0x186,
    "WWxx_xxxx_O": 0x187,
    "WDxW_xxxx_I": 0x188,
    "WDxW_xxxx_O": 0x189,
    "xWxx_xxxx_I": 0x18A,
    "xWxx_xxxx_O": 0x18B,
    "xDxx_xxxx_I": 0x18C,
    "xDxx_xxxx_O": 0x18D,
    "WDxx_xxxx_I": 0x18E,
    "WDxx_xxxx_O": 0x18F,
    "Wxxx_xxxx_I": 0x190,
    "Wxxx_xxxx_O": 0x191,
    "WxxW_xxxx_I": 0x192,
    "WxxW_xxxx_O": 0x193,
    "WWWx_xxxx_I": 0x194,
    "WWWx_xxxx_O": 0x195,
    "DDDW_xxxx_I": 0x196,
    "DDDW_xxxx_O": 0x197,
    "xDDW_xxxx_I": 0x19A,
    "xDDW_xxxx_O": 0x19B,
    "WWDx_xxxx_I": 0x19C,
    "WWDx_xxxx_O": 0x19D,
    "xWWD_xxxx_I": 0x1A0,
    "xWWD_xxxx_O": 0x1A1,
    "WWWD_xxxx_I": 0x1A2,
    "WWWD_xxxx_O": 0x1A3,
    "xxxx_xxxx_I": 0x1A4,
    "xxxx_xxxx_O": 0x1A5,
    "WWxD_xxxx_I": 0x1A6,
    "WWxD_xxxx_O": 0x1A7,
    "xWWx_xxxx_I": 0x1A8,
    "xWWx_xxxx_O": 0x1A9,
    "DDWW_xxxx_I": 0x1AA,
    "DDWW_xxxx_O": 0x1AB,
}
